from inquirer.render.console._text import Text


class Password(Text):
    def get_current_value(self):
        return self.question.echo * len(self.current) + (self.terminal.move_left * self.cursor_offset)

    def handle_validation_error(self, error):
        if error.reason:
            return error.reason

        return f"Entered value is not a valid {self.question.name}."



from inquirer.prompt import prompt
from inquirer.questions import Checkbox
from inquirer.questions import Confirm
from inquirer.questions import Editor
from inquirer.questions import List
from inquirer.questions import Password
from inquirer.questions import Path
from inquirer.questions import Text
from inquirer.questions import load_from_dict
from inquirer.questions import load_from_json
from inquirer.questions import load_from_list
from inquirer.shortcuts import checkbox
from inquirer.shortcuts import confirm
from inquirer.shortcuts import editor
from inquirer.shortcuts import list_input
from inquirer.shortcuts import password
from inquirer.shortcuts import text


__all__ = [
    "prompt",
    "Text",
    "Editor",
    "Password",
    "Confirm",
    "List",
    "Checkbox",
    "Path",
    "load_from_list",
    "load_from_dict",
    "load_from_json",
    "text",
    "editor",
    "password",
    "confirm",
    "list_input",
    "checkbox",
]
